@@ -113,8 +113,8 @@ module SiSU_Concordance
     private
     class DocTitle
       include SiSU_Viz
-      #revisit, both requires (html & shared_xml) needed for stand alone operation (sisu -w [filename])
-      require_relative 'shared_xml'                     # shared_xml.rb
+      #revisit, both requires (html & xml_shared) needed for stand alone operation (sisu -w [filename])
+      require_relative 'xml_shared'                     # xml_shared.rb
       require_relative 'html'                           # html.rb
       def initialize(particulars)
         @particulars,@md=particulars,particulars.md
@@ -202,7 +202,7 @@ WOK
       def initialize(particulars)
         @particulars=particulars
         begin
-          @env,@md,@dal_array=particulars.env,particulars.md,particulars.dal_array
+          @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
           @file=SiSU_Env::FileOp.new(@md)
           @freq=Hash.new(0)
           @dp=@@dp ||=SiSU_Env::InfoEnv.new.digest.pattern
@@ -256,7 +256,7 @@ WOK
       def map_para
         @seg,ocn=nil,nil
         @word_map={}
-        @dal_array.each do |line|
+        @ao_array.each do |line|
           if defined? line.ocn \
           and line.ocn.to_s =~/\d/
             if (line.is ==:heading \
