@@ -66,7 +66,7 @@ module  SiSU_DBI_Discrete                               #% database building
     include SiSU_Param
   require_relative 'db_dbi'                             # db_dbi.rb
     include SiSU_DbDBI
-  require_relative 'shared_html_lite'                   # shared_html_lite.rb
+  require_relative 'html_lite_shared'                   # html_lite_shared.rb
     include SiSU_FormatShared
   require 'fileutils'
     include FileUtils::Verbose
