@@ -75,7 +75,7 @@ module SiSU_DigestView
     end
     def read
       begin
-        @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
+        @env,@md,@ao_array=@particulars.env,@particulars.md,@particulars.ao_array
         unless @opt.act[:quiet][:set]==:on
           tool=(@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
@@ -107,7 +107,7 @@ module SiSU_DigestView
       @@description,@@ds[:digests],@@ds[:tree],@@ds[:summary],@@sc_info=[],[],[],[],[]
       def initialize(particulars) #data='',md='')
         @particulars=particulars
-        @data,@env,@md=@particulars.dal_array,@particulars.env,@particulars.md
+        @data,@env,@md=@particulars.ao_array,@particulars.env,@particulars.md
         SiSU_Env::FileOp.new(@md).mkdir
         @@dg ||=@env.digest.type
         @@dl ||=@env.digest.length
@@ -120,7 +120,7 @@ module SiSU_DigestView
       def songsheet
         @@description,@@ds[:digests],@@ds[:tree],@@ds[:summary],@@sc_info=[],[],[],[],[]
         message_digest
-        dal_structure
+        ao_structure
         supplementary
         output
       end
@@ -132,11 +132,11 @@ module SiSU_DigestView
         puts f if @md.opt.act[:verbose_plus][:set]==:on
         @@ds[:digests] << f + "\n"
       end
-      def dal_structure_tree(f,e='')
+      def ao_structure_tree(f,e='')
         puts f + e.to_s if @md.opt.act[:verbose_plus][:set]==:on
         @@ds[:tree] << f << e
       end
-      def dal_structure_summary(f,e='')
+      def ao_structure_summary(f,e='')
         puts f + e.to_s if @md.opt.act[:verbose_plus][:set]==:on
         @@ds[:summary] << f << e
       end
@@ -302,7 +302,7 @@ module SiSU_DigestView
         description("Document Digests\n")
         description(a)
       end
-      def dal_structure
+      def ao_structure
         data=@data
         endnotes=nil
         data.each do |t_o|
@@ -330,8 +330,8 @@ module SiSU_DigestView
         end
         l=Hash.new(0)
         ocn=nil
-        dal_structure_tree("------------\n")
-        dal_structure_tree("document structure[*]\n")
+        ao_structure_tree("------------\n")
+        ao_structure_tree("document structure[*]\n")
         data.each do |t_o|
           if t_o.is==:heading
             x=case t_o.ln
@@ -351,11 +351,11 @@ module SiSU_DigestView
             end
           end
           ocn=t_o.ocn if defined? t_o.ocn and t_o.is !=:heading_insert
-          dal_structure_tree("#{x}\n") if x and not x.empty?
+          ao_structure_tree("#{x}\n") if x and not x.empty?
         end
-        dal_structure_tree("  [*] heading levels\n")
-        dal_structure_summary("------------\n")
-        dal_structure_summary("document structure[*]\n")
+        ao_structure_tree("  [*] heading levels\n")
+        ao_structure_summary("------------\n")
+        ao_structure_summary("document structure[*]\n")
         [0,1,2,3,4,5,6].each do |y|
           v=case y
           when 1; ':A'
@@ -365,11 +365,11 @@ module SiSU_DigestView
           when 5; '2 '
           when 6; '3 '
           end
-          dal_structure_summary("#{v}            = #{l[y]}\n") if l[y] > 0
+          ao_structure_summary("#{v}            = #{l[y]}\n") if l[y] > 0
         end
-        dal_structure_summary("objects (ocn) = #{ocn}\n")
-        dal_structure_summary("endnotes      = #{endnotes}\n")
-        dal_structure_summary("  [*] number of headers (@) and of each heading level (:A to :C and 1 to 3)\n")
+        ao_structure_summary("objects (ocn) = #{ocn}\n")
+        ao_structure_summary("endnotes      = #{endnotes}\n")
+        ao_structure_summary("  [*] number of headers (@) and of each heading level (:A to :C and 1 to 3)\n")
       end
       def supplementary
         if defined? @md.sc_number \
