@@ -93,7 +93,7 @@ module SiSU_HTML_Format
   end
   class HeadInformation
     require_relative 'css'                              # css.rb
-    require_relative 'shared_xml'                       # shared_xml.rb
+    require_relative 'xml_shared'                       # xml_shared.rb
     include SiSU_Viz
     attr_reader :md,:rdf,:vz
     def initialize(md)
@@ -904,7 +904,7 @@ WOK
         @lnk_url        =t_o[:lnk_url]        || nil
         @lnk_txt        =t_o[:lnk_txt]        || nil
         @format         =t_o[:format]         || nil
-      elsif t_o.class.inspect =~/^(?:#<)?SiSU_DAL_DocumentStructure/
+      elsif t_o.class.inspect =~/^(?:#<)?SiSU_AO_DocumentStructure/
         @dob=t_o if defined? t_o.is
         @named=nametags_seg(@dob)
         @txt=((defined? t_o.obj) ? t_o.obj : nil)
