@@ -60,7 +60,7 @@
 
 =end
 module SiSU_HTML_Seg
-  require_relative 'shared_html'                        # shared_html.rb
+  require_relative 'html_shared'                        # html_shared.rb
   require_relative 'html'                               # html.rb
   require_relative 'html_promo'                         # html_promo.rb
   require_relative 'shared_metadata'                    # shared_metadata.rb
