@@ -66,7 +66,7 @@ module SiSU_XHTML
     include SiSU_Particulars
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
-  require_relative 'shared_xml'                         # shared_xml.rb
+  require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
   require_relative 'xml_format'                         # xml_format.rb
     include SiSU_XML_Format
@@ -82,7 +82,7 @@ module SiSU_XHTML
     end
     def read
       begin
-        @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
+        @env,@md,@ao_array=@particulars.env,@particulars.md,@particulars.ao_array
         unless @opt.act[:quiet][:set]==:on
           tool=if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
@@ -113,7 +113,7 @@ module SiSU_XHTML
     private
     class Songsheet
       def initialize(particulars)
-        @env,@md,@dal_array,@particulars=particulars.env,particulars.md,particulars.dal_array,particulars
+        @env,@md,@ao_array,@particulars=particulars.env,particulars.md,particulars.ao_array,particulars
         @file=SiSU_Env::FileOp.new(@md)
       end
       def song
@@ -134,13 +134,13 @@ module SiSU_XHTML
       end
     end
     class Scroll
-      require_relative 'shared_xhtml'                   # shared_xhtml.rb #check already called
-      require_relative 'shared_txt'                     # shared_txt.rb
+      require_relative 'xhtml_shared'                   # xhtml_shared.rb #check already called
+      require_relative 'txt_shared'                     # txt_shared.rb
         include SiSU_TextUtils
       require_relative 'css'                            # css.rb
       @@xml={ body: [], sisu: [], open: [], close: [], head: [] }
       def initialize(particulars)
-        @env,@md,@dal_array=particulars.env,particulars.md,particulars.dal_array
+        @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
         @vz=SiSU_Viz::Defaults.new
         @tab="\t"
         @trans=SiSU_XML_Munge::Trans.new(@md)
@@ -148,7 +148,7 @@ module SiSU_XHTML
       end
       def songsheet
         pre
-        @data=markup(@dal_array)
+        @data=markup(@ao_array)
         post
         publish
       end
