@@ -66,8 +66,8 @@ module SiSU_XML_DOM
     include SiSU_Particulars
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
-  require_relative 'dal'                                # dal.rb
-  require_relative 'shared_xml'                         # shared_xml.rb
+  require_relative 'ao'                                 # ao.rb
+  require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
   require_relative 'xml_format'                         # xml_format.rb
     include SiSU_XML_Format
@@ -83,7 +83,7 @@ module SiSU_XML_DOM
     end
     def read
       begin
-        @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
+        @env,@md,@ao_array=@particulars.env,@particulars.md,@particulars.ao_array
         unless @opt.act[:quiet][:set]==:on
           tool=if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
@@ -114,7 +114,7 @@ module SiSU_XML_DOM
     private
     class Songsheet
       def initialize(particulars)
-        @env,@md,@dal_array,@particulars=particulars.env,particulars.md,particulars.dal_array,particulars
+        @env,@md,@ao_array,@particulars=particulars.env,particulars.md,particulars.ao_array,particulars
         @file=SiSU_Env::FileOp.new(@md)
       end
       def songsheet
@@ -135,19 +135,19 @@ module SiSU_XML_DOM
       end
     end
     class Scroll
-      require_relative 'shared_txt'                     # shared_txt.rb
+      require_relative 'txt_shared'                     # txt_shared.rb
         include SiSU_TextUtils
-      require_relative 'shared_xhtml'                   # decide use, whether xml rather than xhtml
+      require_relative 'xhtml_shared'                   # decide use, whether xml rather than xhtml
       @@xml={ body: [], open: [], close: [], head: [], sc: [] }
       def initialize(particulars)
-        @env,@md,@dal_array=particulars.env,particulars.md,particulars.dal_array
+        @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
         @vz=SiSU_Viz::Defaults.new
         @trans=SiSU_XML_Munge::Trans.new(@md)
         @sys=SiSU_Env::SystemCall.new
       end
       def songsheet
         pre
-        @data=markup(@dal_array)
+        @data=markup(@ao_array)
         post
         publish
       end
